@@ -29,6 +29,12 @@ def fmt(session):
         session.run(tool, '.')
 
 
+@nox.session(python=['3.10'])
+def publish(session):
+    session.install('.[dev]')
+    session.run('flit', 'publish')
+
+
 @nox.session(python=['3.10'])
 def render_readme(session):
     session.install('-e', '.[doc]')
